@@ -39,13 +39,13 @@
 #include <gio/gio.h>
 #include <sys/socket.h>
 
-#include <libfm-qt/mountoperation.h>
-#include <libfm-qt/filepropsdialog.h>
-#include <libfm-qt/filesearchdialog.h>
-#include <libfm-qt/core/terminal.h>
-#include <libfm-qt/core/bookmarks.h>
-#include <libfm-qt/core/folderconfig.h>
-#include <libfm-qt/core/fileinfojob.h>
+#include <libfm-qt6/mountoperation.h>
+#include <libfm-qt6/filepropsdialog.h>
+#include <libfm-qt6/filesearchdialog.h>
+#include <libfm-qt6/core/terminal.h>
+#include <libfm-qt6/core/bookmarks.h>
+#include <libfm-qt6/core/folderconfig.h>
+#include <libfm-qt6/core/fileinfojob.h>
 
 #include "applicationadaptor.h"
 #include "applicationadaptorfreedesktopfilemanager.h"
@@ -331,15 +331,17 @@ bool Application::parseCommandLineArgs() {
 void Application::init() {
 
     // install the translations built-into Qt itself
-    qtTranslator.load(QStringLiteral("qt_") + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
-    installTranslator(&qtTranslator);
+    if(qtTranslator.load(QStringLiteral("qt_") + QLocale::system().name(), QLibraryInfo::path(QLibraryInfo::TranslationsPath))) {
+        installTranslator(&qtTranslator);
+    }
 
     // install libfm-qt translator
     installTranslator(libFm_.translator());
 
-    // install our own translations
-    translator.load(QStringLiteral("pcmanfm-qt_") + QLocale::system().name(), QStringLiteral(PCMANFM_DATA_DIR) + QStringLiteral("/translations"));
-    installTranslator(&translator);
+    // install our own tranlations
+    if(translator.load(QStringLiteral("pcmanfm-qt_") + QLocale::system().name(), QStringLiteral(PCMANFM_DATA_DIR) + QStringLiteral("/translations"))) {
+        installTranslator(&translator);
+    }
 }
 
 int Application::exec() {
@@ -392,10 +394,6 @@ void Application::onUserDirsChanged() {
 
 void Application::onAboutToQuit() {
     qDebug("aboutToQuit");
-    // save custom positions of desktop items
-    if(!desktopWindows_.isEmpty()) {
-        desktopWindows_.first()->saveItemPositions();
-    }
 
     settings_.save();
 }
@@ -575,7 +573,7 @@ void Application::launchFiles(const QString& cwd, const QStringList& paths, bool
         settings_.setTabPaths(QStringList());
     }
 
-    for(const QString& it : qAsConst(_paths)) {
+    for(const QString& it : std::as_const(_paths)) {
         QByteArray pathName = it.toLocal8Bit();
         Fm::FilePath path;
         if(pathName == "~") { // special case for home dir
@@ -700,7 +698,7 @@ void Application::setWallpaper(const QString& path, const QString& modeString) {
     // update wallpaper
     if(changed) {
         if(enableDesktopManager_) {
-            for(DesktopWindow* desktopWin :  qAsConst(desktopWindows_)) {
+            for(DesktopWindow* desktopWin :  std::as_const(desktopWindows_)) {
                 if(!path.isEmpty()) {
                     desktopWin->setWallpaperFile(path);
                 }
@@ -824,6 +822,7 @@ DesktopWindow* Application::createDesktopWindow(int screenNum) {
 
     window->updateFromSettings(settings_);
     window->show();
+    window->queueRelayout(); // for some reason, sometimes needed with Qt6
     return window;
 }
 
@@ -1015,7 +1014,7 @@ void Application::onScreenDestroyed(QObject* screenObj) {
     if(enableDesktopManager_) {
         bool reloadNeeded = false;
         // FIXME: add workarounds for Qt5 bug #40681 and #40791 here.
-        for(DesktopWindow* desktopWin :  qAsConst(desktopWindows_)) {
+        for(DesktopWindow* desktopWin :  std::as_const(desktopWindows_)) {
             if(desktopWin->windowHandle()->screen() == screenObj) {
                 desktopWin->destroy(); // destroy the underlying native window
                 reloadNeeded = true;
@@ -1030,7 +1029,7 @@ void Application::onScreenDestroyed(QObject* screenObj) {
 void Application::reloadDesktopsAsNeeded() {
     if(enableDesktopManager_) {
         // workarounds for Qt5 bug #40681 and #40791 here.
-        for(DesktopWindow* desktopWin : qAsConst(desktopWindows_)) {
+        for(DesktopWindow* desktopWin : std::as_const(desktopWindows_)) {
             if(!desktopWin->windowHandle()) {
                 desktopWin->create(); // re-create the underlying native window
                 desktopWin->queueRelayout();
@@ -1043,7 +1042,7 @@ void Application::reloadDesktopsAsNeeded() {
 void Application::onVirtualGeometryChanged(const QRect& /*rect*/) {
     // update desktop geometries
     if(enableDesktopManager_) {
-        for(DesktopWindow* desktopWin : qAsConst(desktopWindows_)) {
+        for(DesktopWindow* desktopWin : std::as_const(desktopWindows_)) {
             auto desktopScreen = desktopWin->getDesktopScreen();
             if(desktopScreen) {
                 desktopWin->setGeometry(desktopScreen->virtualGeometry());
@@ -1055,7 +1054,7 @@ void Application::onVirtualGeometryChanged(const QRect& /*rect*/) {
 void Application::onAvailableGeometryChanged(const QRect& /*rect*/) {
     // update desktop layouts
     if(enableDesktopManager_) {
-        for(DesktopWindow* desktopWin : qAsConst(desktopWindows_)) {
+        for(DesktopWindow* desktopWin : std::as_const(desktopWindows_)) {
             desktopWin->queueRelayout();
         }
     }
